@charset "utf-8";
/* Stylesheet for the Opera image viewer */
/* Copyright 2012 Opera Software */
html {
    background-color: hsl(0,0%,98%);
    display: table;
    width: 100%;
    height: 100%;
}
img {
    display: block;
    margin: auto;
}
body {
    margin: 0;
    padding: 8px;
    display: table-cell;
    vertical-align: middle;
}

@media projection, tv, handheld {
	html {background-color: black;}
	body {background-color: hsl(0,0%,39%);}
	img {background-color: hsl(0,0%,98%);}
}
